/****************************************************************************************
Mat 259 : Project 3 Student Defined Visualization Project
"MLB Pitchers: Winning Percentage Across Other Metrics"
                                                     
Author: Brianna Griffin                        
Supervisor: George Legrady                           

Purpose: Show relationships between the winning percentage and other statistics of 
         pitchers in the MLB. Present multi-dimensional data in a 3D environment.

Usage:    1. A mouse left-drag will rotate the camera around the subject. 
          3. 'DIRECT' - plots points on the correspond x/y/z axes showing their 
                        respective direct relationships
          4. 'LABELS' - removes the labels on the axes
          5. 'CUBES' - removes the cubes
          6. 'AGE_19_24' - removes points with 19≤age≤24 years old
          7. 'AGE_25_29' - removes points with 25≤age≤29 years old
          8. 'AGE_30_34' - removes points with 30≤age≤34 years old
          9. 'AGE_35_39' - removes points with 35≤age≤39 years old
          10.'AGE_40_44' - removes points with 40≤age≤44 years old
          11.'AGE_45_49' - removes points with 45≤age≤49 years old
          12.'ROTATE_CAM' - rotates the camera view along the x-axis
          13.'INITIAL' - positions the camera at the initial point of view
(color of the curve/point denotes the age of the pitcher; grouped into 6 categories of 
 5 years)

NOTE: the z-axis is consistently the winning percentage for each pitcher while the x 
      and y axes change for each cube
****************************************************************************************/
import peasy.*; 
import controlP5.*;

ControlP5 cp5; 
PeasyCam cam;

Table table;
int numRows; 
ArrayList<Player> people = new ArrayList<Player>();
boolean labels;
boolean cubes; 
boolean age_19_24;
boolean age_25_29;
boolean age_30_34;
boolean age_35_39;
boolean age_40_44;
boolean age_45_49;
boolean direct;
 

void setup(){
  size(1500, 800, P3D); 
  cam = new PeasyCam(this, 200); 
  
  cam.lookAt(300, 100, 100);
  
  cam.setMinimumDistance(20); 
  cam.setMaximumDistance(1500); 
  
  // Set up the GUI
  cp5 = new ControlP5(this);
  labels = true;
  cubes = true; 
  age_19_24 = true;
  age_25_29 = true;
  age_30_34 = true ;
  age_35_39 = true ;
  age_40_44 = true ;
  age_45_49 = true ;
  direct = false; 
  setGui();
  
  table = loadTable("mlb_data.csv", "header");
  numRows = table.getRowCount();
  
  for(int i=0; i<numRows; i++){
  String age = table.getString(i,0);
  String team = table.getString(i,1);
  float ip = table.getFloat(i,2);
  float nd = table.getFloat(i,3);
  float wchp = table.getFloat(i,4);
  float ltuf = table.getFloat(i,5);
  float wtm = table.getFloat(i,6);
  float ltm = table.getFloat(i,7);
  float tm_w_l_percent = table.getFloat(i,8);
  float wlst = table.getFloat(i,9);
  float lsv = table.getFloat(i,10);
  float cg = table.getFloat(i,11);
  float sho = table.getFloat(i,12);
  float qs = table.getFloat(i,13); 
  float qs_percent = table.getFloat(i,14); 
  float gm_sc_a = table.getFloat(i,15); 
  float best = table.getFloat(i,16); 
  float wrst = table.getFloat(i,17); 
  float bqr = table.getFloat(i,18); 
  float s_dr = table.getFloat(i,19); 
  float l_dr = table.getFloat(i,20); 
  float rs_gs = table.getFloat(i,21); 
  float ip_gs = table.getFloat(i,22); 
  float pit_gs = table.getFloat(i,23); 
  float x80 = table.getFloat(i,24); 
  float x80_99 = table.getFloat(i,25); 
  float x100_119 = table.getFloat(i,26); 
  float x120 = table.getFloat(i,27); 
  float max1 = table.getFloat(i,28); 
  float year = table.getFloat(i,29); 
  String cy_status = table.getString(i,30); 
  float w_pct = table.getFloat(i,31); 
  String arm = table.getString(i,32); 
  people.add(new Player(age,team,ip,nd,wchp,ltuf,wtm,ltm,tm_w_l_percent,wlst,lsv,cg,sho,qs,qs_percent,gm_sc_a,best,wrst,bqr,s_dr,l_dr,rs_gs,ip_gs,pit_gs,x80,x80_99,x100_119,x120,max1,year,cy_status,w_pct,arm));
  }

}


void draw(){
  background(0);
  
  
  // cube # 1 (2nd cube from left)
  if (cubes == true){
  pushMatrix(); 
  beginShape(); 
  stroke(255);
  strokeWeight(1);
  translate(100, 100, 100); 
  noFill();
  box(200); 
  endShape();
  popMatrix();
  
  
 
  // cube # 2 (3rd cube from left)
  pushMatrix(); 
  beginShape(); 
  stroke(255);
  strokeWeight(1);
  translate(300, 100, 100); 
  noFill();
  box(200); 
  endShape();
  popMatrix();
  
  
  
  // cube # 3 (left most cube)
  pushMatrix(); 
  beginShape(); 
  stroke(255);
  strokeWeight(1);
  translate(-100, 100, 100); 
  noFill();
  box(200); 
  endShape();
  popMatrix();
  
  
  }
  
  // curves  
  
  // first age group : 19-24
  
  for(int i = 1; i<2000; i++){
  if(people.get(i).age.equals("19-24") && age_19_24 == true && direct == false){
  beginShape(); 
  stroke(lineColor(people.get(i).age)); 
  strokeWeight(0.5); 
  noFill(); 
  // left cube
  curveVertex(-200, 200, 0);
  curveVertex(-200, 200, 0);
  
  // 1
  curveVertex(people.get(i).ip-200, people.get(i).year/100, people.get(i).w_pct*200);
  
  // 2
  curveVertex(people.get(i).best, people.get(i).wrst, people.get(i).w_pct*200);
 
  // 3
  curveVertex(people.get(i).wlst*20+200, people.get(i).lsv*20, people.get(i).w_pct*200);
  
  // 4 
  curveVertex(people.get(i).tm_w_l_percent*200+400, people.get(i).qs_percent*2, people.get(i).w_pct*200);
 
  // 5
  curveVertex(people.get(i).s_dr*50+600, people.get(i).l_dr*10, people.get(i).w_pct*200);
  
  
  // right most cube
  curveVertex(800, 200, 0);
  curveVertex(800, 200, 0);
  endShape();
  }
  }
  
  // second age group: 25_29
for(int i = 1; i<2000; i++){
  if(people.get(i).age.equals("25-29") && age_25_29 == true && direct == false){
  beginShape(); 
  stroke(lineColor(people.get(i).age)); 
  strokeWeight(0.5); 
  noFill(); 
  // left cube
  curveVertex(-200, 200, 0);
  curveVertex(-200, 200, 0);
  
  // 1
  curveVertex(people.get(i).ip-200, people.get(i).year/100, people.get(i).w_pct*200);
  
  // 2
  curveVertex(people.get(i).best, people.get(i).wrst, people.get(i).w_pct*200);
 
  // 3
  curveVertex(people.get(i).wlst*20+200, people.get(i).lsv*20, people.get(i).w_pct*200);
  
  // 4 
  curveVertex(people.get(i).tm_w_l_percent*200+400, people.get(i).qs_percent*2, people.get(i).w_pct*200);
 
  // 5
  curveVertex(people.get(i).s_dr*50+600, people.get(i).l_dr*10, people.get(i).w_pct*200);
  
  
  // right most cube
  curveVertex(800, 200, 0);
  curveVertex(800, 200, 0);
  endShape();
  }
  } 
  
  
  // third age group: 30-34
for(int i = 1; i<2000; i++){
  if(people.get(i).age.equals("30-34") && age_30_34 == true && direct == false){
  beginShape(); 
  stroke(lineColor(people.get(i).age)); 
  strokeWeight(0.5); 
  noFill(); 
  // left cube
  curveVertex(-200, 200, 0);
  curveVertex(-200, 200, 0);
  
  // 1
  curveVertex(people.get(i).ip-200, people.get(i).year/100, people.get(i).w_pct*200);
  
  // 2
  curveVertex(people.get(i).best, people.get(i).wrst, people.get(i).w_pct*200);
 
  // 3
  curveVertex(people.get(i).wlst*20+200, people.get(i).lsv*20, people.get(i).w_pct*200);
  
  // 4 
  curveVertex(people.get(i).tm_w_l_percent*200+400, people.get(i).qs_percent*2, people.get(i).w_pct*200);
 
  // 5
  curveVertex(people.get(i).s_dr*50+600, people.get(i).l_dr*10, people.get(i).w_pct*200);
  
  
  // right most cube
  curveVertex(800, 200, 0);
  curveVertex(800, 200, 0);
  endShape();
  }
  } 
  
  
  // fourth age group: 35_39
for(int i = 1; i<2000; i++){
  if(people.get(i).age.equals("35-39") && age_35_39 == true && direct == false){
  beginShape(); 
  stroke(lineColor(people.get(i).age)); 
  strokeWeight(0.5); 
  noFill(); 
  // left cube
  curveVertex(-200, 200, 0);
  curveVertex(-200, 200, 0);
  
  // 1
  curveVertex(people.get(i).ip-200, people.get(i).year/100, people.get(i).w_pct*200);
  
  // 2
  curveVertex(people.get(i).best, people.get(i).wrst, people.get(i).w_pct*200);
 
  // 3
  curveVertex(people.get(i).wlst*20+200, people.get(i).lsv*20, people.get(i).w_pct*200);
  
  // 4 
  curveVertex(people.get(i).tm_w_l_percent*200+400, people.get(i).qs_percent*2, people.get(i).w_pct*200);
 
  // 5
  curveVertex(people.get(i).s_dr*50+600, people.get(i).l_dr*10, people.get(i).w_pct*200);
  
  
  // right most cube
  curveVertex(800, 200, 0);
  curveVertex(800, 200, 0);
  endShape();
  }
  } 

// fifth age group: 40-44
for(int i = 1; i<2000; i++){
  if(people.get(i).age.equals("40-44") && age_40_44 == true && direct == false){
  beginShape(); 
  stroke(lineColor(people.get(i).age)); 
  strokeWeight(0.5); 
  noFill(); 
  // left cube
  curveVertex(-200, 200, 0);
  curveVertex(-200, 200, 0);
  
  // 1
  curveVertex(people.get(i).ip-200, people.get(i).year/100, people.get(i).w_pct*200);
  
  // 2
  curveVertex(people.get(i).best, people.get(i).wrst, people.get(i).w_pct*200);
 
  // 3
  curveVertex(people.get(i).wlst*20+200, people.get(i).lsv*20, people.get(i).w_pct*200);
  
  // 4 
  curveVertex(people.get(i).tm_w_l_percent*200+400, people.get(i).qs_percent*2, people.get(i).w_pct*200);
 
  // 5
  curveVertex(people.get(i).s_dr*50+600, people.get(i).l_dr*10, people.get(i).w_pct*200);
  
  
  // right most cube
  curveVertex(800, 200, 0);
  curveVertex(800, 200, 0);
  endShape();
  }
  } 
  
// sixth(last!) age group: 45_49
for(int i = 1; i<2000; i++){
  if(people.get(i).age.equals("45-49") && age_45_49 == true && direct == false){
  beginShape(); 
  stroke(lineColor(people.get(i).age)); 
  strokeWeight(0.5); 
  noFill(); 
  // left cube
  curveVertex(-200, 200, 0);
  curveVertex(-200, 200, 0);
  
  // 1
  curveVertex(people.get(i).ip-200, people.get(i).year/100, people.get(i).w_pct*200);
  
  // 2
  curveVertex(people.get(i).best, people.get(i).wrst, people.get(i).w_pct*200);
 
  // 3
  curveVertex(people.get(i).wlst*20+200, people.get(i).lsv*20, people.get(i).w_pct*200);
  
  // 4 
  curveVertex(people.get(i).tm_w_l_percent*200+400, people.get(i).qs_percent*2, people.get(i).w_pct*200);
 
  // 5
  curveVertex(people.get(i).s_dr*50+600, people.get(i).l_dr*10, people.get(i).w_pct*200);
  
  
  // right most cube
  curveVertex(800, 200, 0);
  curveVertex(800, 200, 0);
  endShape();
  }
  } 

 
  if (cubes == true){
  // cube # 4 (4th cube from left)
  pushMatrix(); 
  beginShape(); 
  stroke(255);
  strokeWeight(1);
  translate(500, 100, 100); 
  noFill();
  box(200); 
  endShape();
  popMatrix();
  

  // cube # 5 (5th cube from left)
  pushMatrix(); 
  beginShape(); 
  stroke(255);
  strokeWeight(1);
  translate(700, 100, 100); 
  noFill();
  box(200); 
  endShape();
  popMatrix();
  }
  
  // Labels
  textAxis();
  gui();
  Direct_Ship();
  GuiLabels();
}
